ctt_table() produces a table with classical test theory estimates.
Usage
ctt_table(data, scale_num, scale_info)
Arguments
- data
a data frame, where rows = observations, and columns = variables
- scale_num
a number, that identifies a unique set of items within the scale_info table
- scale_info
a data frame where items memmbership to scale is uniquely identify
Value
data frame with CTT estimates, generated with CTT::itemAnalysis()
Examples
ctt_table(
data = scale_data,
scale_num = 1,
scale_info = items_data
) %>%
knitr::kabel(., digits = 2)
#> Error in ctt_table(data = scale_data, scale_num = 1, scale_info = items_data) %>% knitr::kabel(., digits = 2): could not find function "%>%"