fit_grm2_align() it fits a between country GRM with alignment method using MPLUS and MplusAutomation
Usage
fit_grm2_align(data, scale_num, scale_info)
Arguments
- data
a data frame, where rows = observations, and columns = variables
- scale_num
a number, that identifies a unique set of items within the scale_info table
- scale_info
a data frame where items memmbership to scale is uniquely identify
Value
mplus_object generated with MplusAutomation
Examples
scale_001_lign <- fit_grm2_align(
scale_info = scales_data,
scale_num = 1,
data = data_model)
#> Error: object 'data_model' not found