fit_grm2_align_w_wlsmv() it fits a between country GRM with alignment method, with a complex sample design using MPLUS and MplusAutomation. The "w" accounts for survey weights alone.
Source:R/fit_grm2_align_w_wlsmv.r
fit_grm2_align_w_wlsmv.Rdfit_grm2_align_w_wlsmv() it fits a between country GRM with alignment method, with a complex sample design using MPLUS and MplusAutomation. The "w" accounts for survey weights alone.
Examples
scale_001_align <- fit_grm2_align_wlsmv(
scale_info = scales_data,
scale_num = 1,
data = data_model)
#> Error: object 'data_model' not found