fit_grm2_align_wjs_wlsmv() it fits a between country GRM with alignment method, with a complex sample design using MPLUS and MplusAutomation. The "wjs" version uses taylor series linearization, using strafication, clusters and weights.
Source:R/fit_grm2_align_wjs_wlsmv.r
fit_grm2_align_wjs_wlsmv.Rdfit_grm2_align_wjs_wlsmv() it fits a between country GRM with alignment method, with a complex sample design using MPLUS and MplusAutomation. The "wjs" version uses taylor series linearization, using strafication, clusters and weights.
Examples
scale_001_align <- fit_grm2_align_wlsmv(
scale_info = scales_data,
scale_num = 1,
data = data_model)
#> Error: object 'data_model' not found