fit_grm2_clu() it fits a graded response model (GRM) using MPLUS and MplusAutomation with clustered errors
Usage
fit_grm2_clu(data, scale_num, scale_info)
Arguments
- data
a data frame, where rows = observations, and columns = variables
- scale_num
a number, that identifies a unique set of items within the scale_info table
- scale_info
a data frame where items memmbership to scale is uniquely identify
Value
mplus_object generated with MplusAutomation
Examples
scale_001 <- fit_grm2_clu(
scale_info = scales_data,
scale_num = 1,
data = data_model)
#> Error: object 'data_model' not found