fit_grm2_m01_strict() it fits a graded response model (GRM) using MPLUS and MplusAutomation
Source:R/fit_grm2_m01_strict.r
fit_grm2_m01_strict.Rdfit_grm2_m01_strict() it fits a graded response model (GRM) using MPLUS and MplusAutomation
Arguments
- data
a data frame, where rows = observations, and columns = variables
- scale_num
a number, that identifies a unique set of items within the scale_info table
- scale_info
a data frame where items memmbership to scale is uniquely identify
- grp_var
group variable (as numeric)
- grp_txt
group variable (as text)
- grp_ref
reference group