Skip to contents

fit_grm2_m03_wj_config() it fits a graded response model (GRM) using MPLUS and MplusAutomation

Usage

fit_grm2_m03_config(data, scale_num, scale_info, grp_var, grp_txt, grp_ref)

Arguments

data

a data frame, where rows = observations, and columns = variables

scale_num

a number, that identifies a unique set of items within the scale_info table

scale_info

a data frame where items memmbership to scale is uniquely identify

grp_var

group variable (as numeric)

grp_txt

group variable (as text)

grp_ref

reference group

Value

mplus_object generated with MplusAutomation

Examples


inv_3 <- fit_grm2_m03_wj_config(
         data = data_model, 
         scale_num = scale_id, 
         scale_info = scales_data,
         grp_var = 'id_k',
         grp_txt = 'CNTRY',
         grp_ref = 'CHL'
         )
#> Error: object 'scale_id' not found