Skip to contents

get_desc() produces a table with descriptives where items or variables are rows and columns are differerent descriptive values. its largely based on the deprecated function skimr::skim_to_wide

Usage

get_desc(x)

Arguments

x

a data frame, where rows = observations, and columns = variables

Value

data frame with with descriptive values

Examples


get_desc(items_data)
#> Error in library(dplyr): there is no package called ‘dplyr’