Skip to contents

get_theta() retrieves the theta score generated with techr::fit_grm2 or techr::fit_pcm

Usage

get_theta(model, name)

Arguments

model

an mplus object generated with techr::fit_grm2 or techr::fit_pcm

name

the name of the score included in the returned data frame

Value

data frame with id_i and a score vector with the defined name

Examples


theta_01 <- fit_grm2(
            scale_info = scales_data,
            scale_num  = 1,
            data = data_model) %>%
            get_theta(., 'score')
#> Error in fit_grm2(scale_info = scales_data, scale_num = 1, data = data_model) %>%     get_theta(., "score"): could not find function "%>%"