plot_error() plot a scatter of errors and theta locations with their histograms, using library(ggplot2)
Source:R/plot_error.r
plot_error.Rdplot_error() plot a scatter of errors and theta locations with their histograms, using library(ggplot2)