plot_error_plain() plot a scatter of errors and theta locations with their histograms, using library(ggplot2)
Source:R/plot_error_plain.r
plot_error_plain.Rdplot_error_plain() plot a scatter of errors and theta locations with their histograms, using library(ggplot2)
Examples
plot_error(scale_001)
#> Error: object 'scale_001' not found