plot_infit() plot infit results from a Rasch model over a response data frame
Source:R/plot_infit.r
plot_infit.Rdplot_infit() plot infit results from a Rasch model over a response data frame
R/plot_infit.r
plot_infit.Rdplot_infit() plot infit results from a Rasch model over a response data frame