Skip to contents

plot_item_map_grm3() generates an item person map using a GRM model with 4 response categories

Usage

plot_item_map_grm3(scale_info, scale_num, model)

Arguments

scale_info

a data frame where items memmbership to scale is uniquely identify

scale_num

a number, that identifies a unique set of items within the scale_info table

model

it uses an input a mplus_object generated with MplusAutomation

Value

a item map plot generated with library(ggplot2)

Examples


plot_item_map_grm3(scales_data, 2, scale_002)
#> Loading required package: dplyr
#> Loading required package: tidyr
#> Loading required package: ggplot2
#> Loading required package: ggpubr
#> Error: object 'scale_002' not found