scale_infit() generates a infit table results from a Rasch model over a response data frame
Usage
scale_infit(data, scale_num, scale_info)
Arguments
- data
a data frame, where rows = observations, and columns = variables
- scale_num
a number, that identifies a unique set of items within the scale_info table
- scale_info
a data frame where items memmbership to scale is uniquely identify
Value
a table of infit results, generated with TAM::tam.fit, showing only those satisfying the condition 'abs(Infit_t) >2 & Infit > 1.33 | abs(Infit_t) >2 & Infit < .75)'
Examples
scale_infit(
data = scale_data,
scale_num = 1,
scale_info = items_data
) %>%
knitr::kabel(., digits = 2)
#> Error in scale_infit(data = scale_data, scale_num = 1, scale_info = items_data) %>% knitr::kabel(., digits = 2): could not find function "%>%"