Skip to contents

silent() suppresses and hides other functions messages and warnings. Its ideal use if to wrapped functions within dynamic reports.

Usage

silent(x)

Arguments

x

a function wrapping its inputs

Value

a the product of the wrapped function without messages and warnings

Examples


table <- items_data %>%
         psych::alpha() %>%
         silent()
#> Error in items_data %>% psych::alpha() %>% silent(): could not find function "%>%"