get_score() retrieves the theta score and re-scale these at mean zero, and sd one at the population level
Source:R/get_score.r
get_score.Rdget_score() retrieves the theta score and re-scale these at mean zero, and sd one at the population level
Examples
score_01 <- fit_grm2(
scale_info = scales_data,
scale_num = 1,
data = data_model) %>%
get_score(., 'score')
#> Error in fit_grm2(scale_info = scales_data, scale_num = 1, data = data_model) %>% get_score(., "score"): could not find function "%>%"