silent() suppresses and hides other functions messages and warnings. Its ideal use if to wrapped functions within dynamic reports.
Source:R/silent.r
silent.Rdsilent() suppresses and hides other functions messages and warnings. Its ideal use if to wrapped functions within dynamic reports.